pub(crate) struct MaybeTransmutableQuery<L, C>where
C: QueryContext,{
src: L,
dst: L,
assume: Assume,
context: C,
}Fields
src: Ldst: Lassume: Assumecontext: CImplementations
Sourceimpl<'tcx> MaybeTransmutableQuery<Ty<'tcx>, TyCtxt<'tcx>>
impl<'tcx> MaybeTransmutableQuery<Ty<'tcx>, TyCtxt<'tcx>>
Sourceimpl<L, C> MaybeTransmutableQuery<L, C>where
C: QueryContext,
impl<L, C> MaybeTransmutableQuery<L, C>where
C: QueryContext,
Sourceimpl<C> MaybeTransmutableQuery<Tree<<C as QueryContext>::Def, <C as QueryContext>::Region, <C as QueryContext>::Type>, C>where
C: QueryContext,
impl<C> MaybeTransmutableQuery<Tree<<C as QueryContext>::Def, <C as QueryContext>::Region, <C as QueryContext>::Type>, C>where
C: QueryContext,
Sourcepub(crate) fn answer(
self,
) -> Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>
pub(crate) fn answer( self, ) -> Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>
Answers whether a Tree is transmutable into another Tree.
Removes definition markers from both trees and, unless safety is assumed,
prunes destination paths that may carry safety invariants. It then converts
the remaining layouts to Dfas and compares them.
Sourceimpl<C> MaybeTransmutableQuery<Dfa<<C as QueryContext>::Region, <C as QueryContext>::Type>, C>where
C: QueryContext,
impl<C> MaybeTransmutableQuery<Dfa<<C as QueryContext>::Region, <C as QueryContext>::Type>, C>where
C: QueryContext,
Sourcepub(crate) fn answer(
self,
) -> Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>
pub(crate) fn answer( self, ) -> Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>
Answers whether a Dfa is transmutable into another Dfa.
fn answer_memo( &self, cache: &mut Map<(State, State), Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>>, src_state: State, dst_state: State, ) -> Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>
fn answer_impl( &self, cache: &mut Map<(State, State), Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>>, src_state: State, dst_state: State, ) -> Answer<<C as QueryContext>::Region, <C as QueryContext>::Type>